@@ -358,18 +358,24 @@ cfg_node_get(
     return CFG_OK;
 }
 
-/* return root node */
+/* get and/or set root node */
 cfg_rc_t
 cfg_node_root(
     cfg_t *cfg,
-    cfg_node_t **node)
+    cfg_node_t  *node,
+    cfg_node_t **node_old)
 {
     /* argument sanity checking */
-    if (cfg == NULL || node == NULL)
+    if (cfg == NULL || (node == NULL && node_old == NULL))
         return CFG_ERR_ARG;
 
-    /* just return the root pointer */
-    *node = cfg->root;
+    /* optionally get old root node pointer */
+    if (node_old != NULL)
+        *node_old = cfg->root;
+
+    /* optionally set new root node pointer */
+    if (node != NULL)
+        cfg->root = node;
 
     return CFG_OK;
 }
